@@ -5,8 +5,10 @@ import json
 import requests
 import math
 import re
+import time
 from .auth import Auth
 from sys import getsizeof
+from datetime import datetime
 
 class _DataFrame:
     app_id = None
@@ -285,8 +287,7 @@ class _DataFrame:
                 portion.reset_index(inplace=True, drop=True)
                 if 'index' in portion:
                      portion = portion.drop(columns=["index"])
-                
-                portion.index += offset + count - (amountSent - 1)
+                portion.index += offset + count + (amountSent + 1)
                 items = json.loads(portion.to_json(orient='index'))
                 
                 response = requests.post(settings.baseURL + 'api/metric/' + self.app_id + '/' + self.collection_id + '/dataframe', json=items, headers={
@@ -297,10 +298,8 @@ class _DataFrame:
                 portion.reset_index(inplace=True, drop=True)
                 if 'index' in portion:
                     portion = portion.drop(columns=["index"])
-                
-                portion.index += offset + count - (amountSent - 1)
+                portion.index += offset + count + (amountSent + 1)
                 items = json.loads(portion.to_json(orient='index'))
-                
                 response = requests.post(settings.baseURL + 'api/metric/' + self.app_id + '/' + self.collection_id + '/dataframe', json=items, headers={
                     'Authorization': 'Bearer ' + settings.token
                 })
